@@ -71,6 +71,7 @@ class PMMail(object):
         track_opens:    Whether or not to track if emails were opened or not
         custom_headers: A dictionary of key-value pairs of custom headers.
         attachments:    A list of tuples or email.mime.base.MIMEBase objects describing attachments.
+        metadata:       A dictionary of key-value pairs of custom metadata. Keys and values can only be strings or ints.
         template_id:    id of Postmark template. See: https://postmarkapp.com/blog/special-delivery-postmark-templates
         template_model: a dictionary containing the values to be loaded into the template
         '''
@@ -90,6 +91,7 @@ class PMMail(object):
         self.__attachments = []
         self.__message_id = None
         #self.__multipart = False
+        self.__metadata = {}
         self.__template_id = None
         self.__template_model = None
 
@@ -108,6 +110,7 @@ class PMMail(object):
             'custom_headers',
             'attachments',
             #'multipart',
+            'metadata',
             'template_id',
             'template_model'
         )
@@ -115,9 +118,9 @@ class PMMail(object):
         for key in kwargs:
             if key in acceptable_keys:
                 if key == 'recipient':
-                    setattr(self, '_PMMail__to', kwargs[key])
+                    setattr(self, 'to', kwargs[key])
                 else:
-                    setattr(self, '_PMMail__%s' % key, kwargs[key])
+                    setattr(self, key, kwargs[key])
 
         # Set up the user-agent
         self.__user_agent = 'Python/%s (python-postmark library version %s)' % ('_'.join([str(var) for var in sys.version_info]), __version__)
@@ -151,6 +154,22 @@ class PMMail(object):
         else:
             raise TypeError('Custom headers must be a dictionary of key-value pairs')
 
+    def _set_metadata(self, value):
+        '''
+        A special set function to ensure
+        we're setting with a dictionary
+        '''
+        if value is None:
+            setattr(self, '_PMMail__metadata', {})
+        elif isinstance(value, dict):
+            for k, v in value.items():
+                if (not isinstance(k, str) and not isinstance(k, int)) \
+                    or (not isinstance(v, str) and not isinstance(v, int)):
+                    raise TypeError('Metadata keys and values can only be strings or integers')
+            setattr(self, '_PMMail__metadata', value)
+        else:
+            raise TypeError('Metadata must be a dictionary of key-value pairs')
+
     def _set_attachments(self, value):
         '''
         A special set function to ensure
@@ -297,6 +316,27 @@ class PMMail(object):
     #     'The API Key for one of your servers on Postmark'
     # )
 
+    metadata = property(
+        lambda self: self.__metadata,
+        _set_metadata,
+        lambda self: setattr(self, '_PMMail_metadata', {}),
+        '''
+        Custom metadata key/value pairs returned by webhooks.
+        '''
+    )
+
+    template_id = property(
+        lambda self: self.__template_id,
+        lambda self, value: setattr(self, '_PMMail__template_id', value),
+        lambda self: setattr(self, '_PMMail__template_id', {}),
+    )
+
+    template_model = property(
+        lambda self: self.__template_model,
+        lambda self, value: setattr(self, '_PMMail__template_model', value),
+        lambda self: setattr(self, '_PMMail__template_model', {}),
+    )
+
     message_id = property(
         lambda self: self.__message_id,
         lambda self, value: setattr(self, '_PMMail__message_id', value),
@@ -393,6 +433,9 @@ class PMMail(object):
                 })
             json_message['Headers'] = cust_headers
 
+        if len(self.__metadata) > 0:
+            json_message['Metadata'] = self.__metadata
+
         if len(self.__attachments) > 0:
             attachments = []
             for attachment in self.__attachments:
